==> CoffeeMud_5_9_6.zip: com/planet_ink/coffee_mud/Locales/Mountains.java <==
package com.planet_ink.coffee_mud.Locales;
import com.planet_ink.coffee_mud.core.interfaces.*;
import com.planet_ink.coffee_mud.core.*;
import com.planet_ink.coffee_mud.core.collections.*;
import com.planet_ink.coffee_mud.Abilities.interfaces.*;
import com.planet_ink.coffee_mud.Areas.interfaces.*;
import com.planet_ink.coffee_mud.Behaviors.interfaces.*;
import com.planet_ink.coffee_mud.CharClasses.interfaces.*;
import com.planet_ink.coffee_mud.Commands.interfaces.*;
import com.planet_ink.coffee_mud.Common.interfaces.*;
import com.planet_ink.coffee_mud.Exits.interfaces.*;
import com.planet_ink.coffee_mud.Items.interfaces.*;
import com.planet_ink.coffee_mud.Libraries.interfaces.*;
import com.planet_ink.coffee_mud.Locales.interfaces.*;
import com.planet_ink.coffee_mud.MOBS.interfaces.*;
import com.planet_ink.coffee_mud.Races.interfaces.*;

import java.util.*;

/*
   Copyright 2001-2017 Bo Zimmerman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

	   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
public class Mountains extends StdRoom
{
	@Override
	public String ID()
	{
		return "Mountains";
	}

	public Mountains()
	{
		super();
		name="the mountain";
		basePhyStats.setWeight(5);
		recoverPhyStats();
	}

	@Override
	public int domainType()
	{
		return Room.DOMAIN_OUTDOORS_MOUNTAINS;
	}

	public static final Integer[] resourceList={
		Integer.valueOf(RawMaterial.RESOURCE_STONE),
		Integer.valueOf(RawMaterial.RESOURCE_IRON),
		Integer.valueOf(RawMaterial.RESOURCE_ALABASTER),
		Integer.valueOf(RawMaterial.RESOURCE_LEAD),
		Integer.valueOf(RawMaterial.RESOURCE_SILVER),
		Integer.valueOf(RawMaterial.RESOURCE_COPPER),
		Integer.valueOf(RawMaterial.RESOURCE_TIN),
		Integer.valueOf(RawMaterial.RESOURCE_AMETHYST),
		Integer.valueOf(RawMaterial.RESOURCE_GARNET),
		Integer.valueOf(RawMaterial.RESOURCE_AMBER),
		Integer.valueOf(RawMaterial.RESOURCE_HERBS),
		Integer.valueOf(RawMaterial.RESOURCE_OPAL),
		Integer.valueOf(RawMaterial.RESOURCE_TOPAZ),
		Integer.valueOf(RawMaterial.RESOURCE_BASALT),
		Integer.valueOf(RawMaterial.RESOURCE_SHALE),
		Integer.valueOf(RawMaterial.RESOURCE_SPICE),
		Integer.valueOf(RawMaterial.RESOURCE_PUMICE),
		Integer.valueOf(RawMaterial.RESOURCE_SANDSTONE),
		Integer.valueOf(RawMaterial.RESOURCE_SOAPSTONE),
		Integer.valueOf(RawMaterial.RESOURCE_AQUAMARINE),
		Integer.valueOf(RawMaterial.RESOURCE_CRYSOBERYL),
		Integer.valueOf(RawMaterial.RESOURCE_ONYX),
		Integer.valueOf(RawMaterial.RESOURCE_TURQUOISE),
		Integer.valueOf(RawMaterial.RESOURCE_DIAMOND),
		Integer.valueOf(RawMaterial.RESOURCE_CRYSTAL),
		Integer.valueOf(RawMaterial.RESOURCE_QUARTZ),
		Integer.valueOf(RawMaterial.RESOURCE_DIRT),
		Integer.valueOf(RawMaterial.RESOURCE_PLATINUM)};
	public static final List<Integer> roomResources=new Vector<Integer>(Arrays.asList(resourceList));

	@Override
	public List<Integer> resourceChoices()
	{
		return Mountains.roomResources;
	}
}

==> CoffeeMud_5_9_8.zip: com/planet_ink/coffee_mud/Locales/Mountains.java <==
package com.planet_ink.coffee_mud.Locales;
import com.planet_ink.coffee_mud.core.interfaces.*;
import com.planet_ink.coffee_mud.core.*;
import com.planet_ink.coffee_mud.core.collections.*;
import com.planet_ink.coffee_mud.Abilities.interfaces.*;
import com.planet_ink.coffee_mud.Areas.interfaces.*;
import com.planet_ink.coffee_mud.Behaviors.interfaces.*;
import com.planet_ink.coffee_mud.CharClasses.interfaces.*;
import com.planet_ink.coffee_mud.Commands.interfaces.*;
import com.planet_ink.coffee_mud.Common.interfaces.*;
import com.planet_ink.coffee_mud.Exits.interfaces.*;
import com.planet_ink.coffee_mud.Items.interfaces.*;
import com.planet_ink.coffee_mud.Libraries.interfaces.*;
import com.planet_ink.coffee_mud.Locales.interfaces.*;
import com.planet_ink.coffee_mud.MOBS.interfaces.*;
import com.planet_ink.coffee_mud.Races.interfaces.*;

import java.util.*;

/*
   Copyright 2001-2019 Bo Zimmerman

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

	   http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
public class Mountains extends StdRoom
{
	@Override
	public String ID()
	{
		return "Mountains";
	}

	public Mountains()
	{
		super();
		name="the mountain";
		basePhyStats.setWeight(5);
		recoverPhyStats();
	}

	@Override
	public int domainType()
	{
		return Room.DOMAIN_OUTDOORS_MOUNTAINS;
	}

	public static final Integer[] resourceList={
		Integer.valueOf(RawMaterial.RESOURCE_STONE),
		Integer.valueOf(RawMaterial.RESOURCE_IRON),
		Integer.valueOf(RawMaterial.RESOURCE_ALABASTER),
		Integer.valueOf(RawMaterial.RESOURCE_LEAD),
		Integer.valueOf(RawMaterial.RESOURCE_SILVER),
		Integer.valueOf(RawMaterial.RESOURCE_COPPER),
		Integer.valueOf(RawMaterial.RESOURCE_TIN),
		Integer.valueOf(RawMaterial.RESOURCE_AMETHYST),
		Integer.valueOf(RawMaterial.RESOURCE_GARNET),
		Integer.valueOf(RawMaterial.RESOURCE_AMBER),
		Integer.valueOf(RawMaterial.RESOURCE_HERBS),
		Integer.valueOf(RawMaterial.RESOURCE_OPAL),
		Integer.valueOf(RawMaterial.RESOURCE_TOPAZ),
		Integer.valueOf(RawMaterial.RESOURCE_BASALT),
		Integer.valueOf(RawMaterial.RESOURCE_SHALE),
		Integer.valueOf(RawMaterial.RESOURCE_SPICE),
		Integer.valueOf(RawMaterial.RESOURCE_PUMICE),
		Integer.valueOf(RawMaterial.RESOURCE_SANDSTONE),
		Integer.valueOf(RawMaterial.RESOURCE_SOAPSTONE),
		Integer.valueOf(RawMaterial.RESOURCE_AQUAMARINE),
		Integer.valueOf(RawMaterial.RESOURCE_CHRYSOBERYL),
		Integer.valueOf(RawMaterial.RESOURCE_ONYX),
		Integer.valueOf(RawMaterial.RESOURCE_TURQUOISE),
		Integer.valueOf(RawMaterial.RESOURCE_DIAMOND),
		Integer.valueOf(RawMaterial.RESOURCE_CRYSTAL),
		Integer.valueOf(RawMaterial.RESOURCE_QUARTZ),
		Integer.valueOf(RawMaterial.RESOURCE_DIRT),
		Integer.valueOf(RawMaterial.RESOURCE_PLATINUM)};
	public static final List<Integer> roomResources=new Vector<Integer>(Arrays.asList(resourceList));

	@Override
	public List<Integer> resourceChoices()
	{
		return Mountains.roomResources;
	}
}
